
# Type: value_description


description of what the value is doing

URI: [meta:value_description](https://w3id.org/biolink/biolinkml/meta/value_description)


## Domain and Range

[Example](Example.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Example](Example.md)
